@@ -4,24 +4,24 @@ use strict;
 
 use vars qw($VERSION @ISA);
 $VERSION = sprintf("%d.%02d", q$Revision: 1.0 $ =~ /(\d+)\.(\d+)/);
-
 use WWW::Search::Scraper::Request;
-{ package WWW::Search::Scraper::Request::Job::_struct_;
-use Class::Struct;
-    struct ( 
-                 '_state'   => '$'
-                ,'_fields'  => '$'
-                ,'_engines' => '%'
-                ,'_native_query' => '$'
-                ,'_native_options' => '$'   # reference to hash of native_options.
-                ,'_Scraper_debug'  => '$'
-                # Now for the Job specific members.
-                ,'skills'    => '$'
-                ,'locations' => '$'
-                ,'payrate'   => '$'
-           );
+@ISA = qw(WWW::Search::Scraper::Request);
+
+#use base qw( WWW::Search::Scraper::Request );
+
+sub new {
+    shift;
+    my $self = WWW::Search::Scraper::Request::new('Job',
+                  ,{   
+                       'skills' => ''
+                      ,'locations' => ''
+                      ,'payrate' => ''
+                   }
+                  ,@_
+               );
+    return $self;
+
 }
-use base qw( WWW::Search::Scraper::Request WWW::Search::Scraper::Request::Job::_struct_);
 
 sub FieldTitles {
     return { 'skills'        => 'Skills'
@@ -30,19 +30,13 @@ sub FieldTitles {
            };
 }
 
-sub new {
-    my $self = new WWW::Search::Scraper::Request::Job::_struct_;
-    bless $self, shift;
-    $self->_init(@_);
-}
-
 1;
 
 __END__
 
 =head1 NAME
 
-WWW::Search::Scraper::Request::Job - Canonical form for Scraper::Job requests
+WWW::Search::Scraper::Request::Job - Canonical Request - skills, locations, payrate
 
 =head1 SYNOPSIS
 
@@ -58,7 +52,7 @@ WWW::Search::Scraper::Request::Job - Canonical form for Scraper::Job requests
 This module provides a canonical taxonomy for specifying requests to search engines (via Scraper modules).
 C<Request::Job> is targeted toward job searches.
 
-See the C<WWW::Search::Scraper::Request> module for a description of how this interfaces with Scraper modules.
+See L<WWW::Search::Scraper::ScraperPOD> or L<WWW::Search::Scraper::Request> for a description of how this interfaces with Scraper modules.
 
 =head1 FIELDS
 
